summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorChad Rosier <mcrosier@apple.com>2012-05-11 23:10:58 +0000
committerChad Rosier <mcrosier@apple.com>2012-05-11 23:10:58 +0000
commit550a08a876760e305dab25bd22f28acf8ffdeb18 (patch)
tree5c6e937237bd66639d62ca333d4ea5d0ee71d20a /lib
parentf5b1e2802f6525a760dab59bb267f6ede15b87e0 (diff)
downloadllvm-550a08a876760e305dab25bd22f28acf8ffdeb18.tar.gz
llvm-550a08a876760e305dab25bd22f28acf8ffdeb18.tar.bz2
llvm-550a08a876760e305dab25bd22f28acf8ffdeb18.tar.xz
[fast-isel] Fast-isel doesn't use the expect intrinsic.
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@156658 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib')
-rw-r--r--lib/CodeGen/SelectionDAG/FastISel.cpp3
1 files changed, 2 insertions, 1 deletions
diff --git a/lib/CodeGen/SelectionDAG/FastISel.cpp b/lib/CodeGen/SelectionDAG/FastISel.cpp
index 0c1ac6982d..cb8ee27993 100644
--- a/lib/CodeGen/SelectionDAG/FastISel.cpp
+++ b/lib/CodeGen/SelectionDAG/FastISel.cpp
@@ -570,9 +570,10 @@ bool FastISel::SelectCall(const User *I) {
// Handle selected intrinsic function calls.
switch (F->getIntrinsicID()) {
default: break;
// At -O0 we don't care about the lifetime intrinsics.
case Intrinsic::lifetime_start:
case Intrinsic::lifetime_end:
+ case Intrinsic::expect:
return true;
case Intrinsic::dbg_declare: {
const DbgDeclareInst *DI = cast<DbgDeclareInst>(Call);
@@ -570,9 +570,10 @@ bool FastISel::SelectCall(const User *I) {
switch (F->getIntrinsicID()) {
default: break;
- // At -O0 we don't care about the lifetime intrinsics.
+ // At -O0 we don't care about the lifetime or expect intrinsics.
case Intrinsic::lifetime_start:
case Intrinsic::lifetime_end: